@@ -1,20 +1,35 @@
 use pyo3::prelude::*;
+use serde_json::Value;
+use crate::binance_connector::BinanceTick;
 
 #[pyclass]
 #[derive(Debug)]
 pub struct TickData {
     #[pyo3(get)]
-    pub(crate) update_id: u64,
+    pub update_id: u64,
     #[pyo3(get)]
-    pub(crate) symbol: String,
+    pub symbol: String,
     #[pyo3(get)]
-    pub(crate) bid: String,
+    pub bid: String,
     #[pyo3(get)]
-    pub(crate) bid_size: String,
+    pub bid_size: String,
     #[pyo3(get)]
-    pub(crate) ask: String,
+    pub ask: String,
     #[pyo3(get)]
-    pub(crate) ask_size: String,  // ask_size
+    pub ask_size: String,  // ask_size
+}
+
+impl From<BinanceTick> for TickData {
+    fn from(value: BinanceTick) -> Self {
+        Self {
+            update_id: value.data.u,
+            symbol: value.data.s,
+            bid: value.data.b,
+            bid_size: value.data.B,
+            ask: value.data.a,
+            ask_size: value.data.A,
+        }
+    }
 }
 
 #[pymethods]
@@ -25,9 +40,10 @@ impl TickData {
         // We use the `format!` macro to create a string. Its first argument is a
         // format string, followed by any number of parameters which replace the
         // `{}`'s in the format string.
-        format!("TickData: bid={bid} ask={ask}",
+        format!("TickData: symbol={symbol} bid={bid} ask={ask}",
                 ask = &self.ask,
                 bid = &self.bid,
+                symbol = &self.symbol,
         )
     }
 
